@@ -2,11 +2,11 @@
 
 ;; Copyright (C) 2016-2018 J. Alexander Branham
 
-;; Author: J. Alexander Branham <branham@utexas.edu>
-;; Maintainer: J. Alexander Branham <branham@utexas.edu>
+;; Author: J. Alexander Branham <alex.branham@gmail.com>
+;; Maintainer: J. Alexander Branham <alex.branham@gmail.com>
 ;; URL: https://gitlab.com/jabranham/system-packages
 ;; Package-Requires: ((emacs "24.3"))
-;; Version: 1.0.7
+;; Version: 1.0.10
 
 
 ;; This file is not part of GNU Emacs.
@@ -42,9 +42,6 @@
 ;;
 
 ;;; Code:
-(eval-when-compile
-  (require 'cl-lib))
-
 (defgroup system-packages nil
   "Manages system packages"
   :tag "System Packages"
@@ -60,7 +57,7 @@
            (search . "guix package -s")
            (uninstall . "guix package -r")
            (update . ("guix package --upgrade"))
-           (clean-cache . nil)
+           (clean-cache . "guix gc")
            (log . nil)
            (get-info . nil)
            (get-info-remote . nil)
@@ -79,7 +76,7 @@
           (search . "nix search")
           (uninstall . "nix-env -e")
           (update . ("nix-env -u" ))
-          (clean-cache . nil)
+          (clean-cache . "nix-collect-garbage")
           (log . nil)
           (get-info . nil)
           (get-info-remote . nil)
@@ -288,10 +285,15 @@ The key is the package manager and values (usually) commands.")
 (define-obsolete-variable-alias 'system-packages-packagemanager
   'system-packages-package-manager "2017-12-25")
 (defcustom system-packages-package-manager
-  (cl-loop for (name . prop) in system-packages-supported-package-managers
-           for path = (executable-find (symbol-name name))
-           when path
-           return name)
+  (let ((managers system-packages-supported-package-managers)
+        manager)
+    (while managers
+      (progn
+        (setq manager (pop managers))
+        (if (executable-find (symbol-name (car manager)))
+            (setq managers nil)
+          (setq manager nil))))
+    (car manager))
   "Symbol containing the package manager to use.
 
 See `system-packages-supported-package-managers' for a list of
